@@ -44,8 +44,8 @@ text-to-HTML conversion tool for web writers.
 #   not yet sure if there implications with this. Compare 'pydoc sre'
 #   and 'perldoc perlre'.
 
-__version_info__ = (1, 0, 1, 10) # first three nums match Markdown.pl
-__version__ = '1.0.1.10'
+__version_info__ = (1, 0, 1, 11) # first three nums match Markdown.pl
+__version__ = '1.0.1.11'
 __author__ = "Trent Mick"
 
 import os
@@ -1742,7 +1742,9 @@ def _test():
     import doctest
     doctest.testmod()
 
-def main(argv=sys.argv):
+def main(argv=None):
+    if argv is None:
+        argv = sys.argv
     if not logging.root.handlers:
         logging.basicConfig()
 
